@@ -8,5 +8,6 @@ class EmbedAccessTokenResponse:
     r"""EmbedAccessTokenResponse
     An EmbedAccessTokenResponse contains a token that can be used to embed a Speakeasy dashboard.
     """
-    access_token: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'access_token' }})
+    
+    access_token: str = field(metadata={'dataclasses_json': { 'field_name': 'access_token' }})
     
